@@ -75,7 +75,7 @@ namespace Breeze
         using SplitterProxyPointer = WeakPointer<SplitterProxy>;
 
         //* registered widgets
-        typedef QMap<QWidget*, SplitterProxyPointer > WidgetMap;
+        using WidgetMap = QMap<QWidget*, SplitterProxyPointer >;
         WidgetMap _widgets;
 
     };
